@@ -4,6 +4,6 @@ echo
 Print all arguments to standard output, separated by spaces.
 """
 
-def main(args):
+def main(*args):
     print(' '.join(args))
     return 0
