@@ -4,5 +4,5 @@ false
 Does nothing except return a status code of 1.
 """
 
-def main(args):
+def main(*args):
     return 1
