@@ -7,6 +7,6 @@ Print the current working directory to standard output.
 import os
 
 
-def main(args):
+def main(*args):
     print(os.getcwd())
     return 0
