@@ -4,7 +4,7 @@ sb_list
 List available slitherbox utilities.
 """
 
-def main(args):
+def main(*args):
     args.sort()
     for util in args:
         print(util)
