@@ -7,7 +7,7 @@ Uninstall slitherbox by removing utility symlinks.
 import os
 
 
-def main(args):
+def main(*args):
     SLITHERBOX_ROOT = args[0]
     utilities = args[1:]
 
@@ -19,5 +19,5 @@ def main(args):
             os.unlink(symlink_path)
             uninstall_count += 1
 
-    print(f'\nUnlinked {uninstall_count} utilities')
+    print(f'\nUnlinked {uninstall_count} utilities from {SLITHERBOX_ROOT}')
     return 0
