@@ -4,5 +4,5 @@ true
 Does nothing except return a status code of 0.
 """
 
-def main(args):
+def main(*args):
     return 0
