@@ -7,7 +7,7 @@ Prints the current user's username to standard output.
 import os
 
 
-def main(args):
+def main(*args):
     if len(args) != 0:
         print('Usage: whoami')
         return 1
